# Luna Moth - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Luna Moth](https://vuldb.com/?actor.luna_moth). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.luna_moth](https://vuldb.com/?actor.luna_moth)

## Campaigns

The following _campaigns_ are known and can be associated with Luna Moth:

* Subscription Scam

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Luna Moth:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [RU](https://vuldb.com/?country.ru)

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Luna Moth.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [23.238.40.28](https://vuldb.com/?ip.23.238.40.28) | hwsrv-979679.hostwindsdns.com | Subscription Scam | High
2 | [23.238.40.29](https://vuldb.com/?ip.23.238.40.29) | hwsrv-979677.hostwindsdns.com | Subscription Scam | High
3 | [23.238.40.30](https://vuldb.com/?ip.23.238.40.30) | hwsrv-979678.hostwindsdns.com | Subscription Scam | High
4 | [23.238.40.31](https://vuldb.com/?ip.23.238.40.31) | hwsrv-979680.hostwindsdns.com | Subscription Scam | High
5 | [23.238.40.32](https://vuldb.com/?ip.23.238.40.32) | hwsrv-979681.hostwindsdns.com | Subscription Scam | High
6 | [23.254.227.79](https://vuldb.com/?ip.23.254.227.79) | client-23-254-227-79.hostwindsdns.com | Subscription Scam | High
7 | [23.254.228.211](https://vuldb.com/?ip.23.254.228.211) | hwsrv-981934.hostwindsdns.com | Subscription Scam | High
8 | [23.254.229.90](https://vuldb.com/?ip.23.254.229.90) | client-23-254-229-90.hostwindsdns.com | Subscription Scam | High
9 | [104.168.135.71](https://vuldb.com/?ip.104.168.135.71) | hwsrv-975503.hostwindsdns.com | Subscription Scam | High
10 | [104.168.164.244](https://vuldb.com/?ip.104.168.164.244) | client-104-168-164-244.hostwindsdns.com | Subscription Scam | High
11 | [104.168.171.104](https://vuldb.com/?ip.104.168.171.104) | hwsrv-979189.hostwindsdns.com | Subscription Scam | High
12 | [104.168.171.231](https://vuldb.com/?ip.104.168.171.231) | hwsrv-979190.hostwindsdns.com | Subscription Scam | High
13 | [104.168.201.87](https://vuldb.com/?ip.104.168.201.87) | client-104-168-201-87.hostwindsdns.com | Subscription Scam | High
14 | [104.168.201.100](https://vuldb.com/?ip.104.168.201.100) | client-104-168-201-100.hostwindsdns.com | Subscription Scam | High
15 | [104.168.201.121](https://vuldb.com/?ip.104.168.201.121) | client-104-168-201-121.hostwindsdns.com | Subscription Scam | High
16 | [104.168.201.129](https://vuldb.com/?ip.104.168.201.129) | client-104-168-201-129.hostwindsdns.com | Subscription Scam | High
17 | [104.168.204.231](https://vuldb.com/?ip.104.168.204.231) | client-104-168-204-231.hostwindsdns.com | Subscription Scam | High
18 | [104.168.218.242](https://vuldb.com/?ip.104.168.218.242) | hwsrv-975504.hostwindsdns.com | Subscription Scam | High
19 | ... | ... | ... | ...

There are 70 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Luna Moth_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | ... | ... | ... | ...

There are 8 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Luna Moth. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/ajax-files/followBoard.php` | High
2 | File | `/includes/lib/detail.php` | High
3 | File | `/modules/projects/vw_files.php` | High
4 | File | `/see_more_details.php` | High
5 | File | `/server-status` | High
6 | File | `add-services.php` | High
7 | File | `admin.php` | Medium
8 | File | `admin/models/Galleries.php` | High
9 | File | `affich.php` | Medium
10 | File | `affiliate-preview.php` | High
11 | File | `akocomments.php` | High
12 | File | `album_portal.php` | High
13 | File | `application/modules/admin/views/ecommerce/products.php` | High
14 | File | `apps/app_article/controller/rating.php` | High
15 | File | `app\Http\Controllers\Backend\ProfileController.php` | High
16 | File | `auktion.cgi` | Medium
17 | File | `basket.php` | Medium
18 | File | `big.php` | Low
19 | File | `category_list.php` | High
20 | File | `closeup.php` | Medium
21 | File | `cng.sys` | Low
22 | File | `comersus_optreviewreadexec.asp` | High
23 | ... | ... | ...

There are 187 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.sygnia.co/luna-moth-false-subscription-scams

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
