# TeslaCrypt - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [TeslaCrypt](https://vuldb.com/?actor.teslacrypt). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.teslacrypt](https://vuldb.com/?actor.teslacrypt)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with TeslaCrypt:

* [US](https://vuldb.com/?country.us)
* [GB](https://vuldb.com/?country.gb)
* [GR](https://vuldb.com/?country.gr)
* ...

There are 19 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of TeslaCrypt.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [2.57.138.47](https://vuldb.com/?ip.2.57.138.47) | s27.zenbox.pl | - | High
2 | [3.93.124.54](https://vuldb.com/?ip.3.93.124.54) | ec2-3-93-124-54.compute-1.amazonaws.com | - | Medium
3 | [3.225.189.10](https://vuldb.com/?ip.3.225.189.10) | ec2-3-225-189-10.compute-1.amazonaws.com | - | Medium
4 | [3.229.167.115](https://vuldb.com/?ip.3.229.167.115) | ec2-3-229-167-115.compute-1.amazonaws.com | - | Medium
5 | [5.79.68.109](https://vuldb.com/?ip.5.79.68.109) | - | - | High
6 | [5.79.68.110](https://vuldb.com/?ip.5.79.68.110) | - | - | High
7 | [13.107.21.200](https://vuldb.com/?ip.13.107.21.200) | - | - | High
8 | [20.42.65.92](https://vuldb.com/?ip.20.42.65.92) | - | - | High
9 | [20.189.173.20](https://vuldb.com/?ip.20.189.173.20) | - | - | High
10 | [20.189.173.22](https://vuldb.com/?ip.20.189.173.22) | - | - | High
11 | [23.20.239.12](https://vuldb.com/?ip.23.20.239.12) | ec2-23-20-239-12.compute-1.amazonaws.com | - | Medium
12 | [23.63.245.19](https://vuldb.com/?ip.23.63.245.19) | a23-63-245-19.deploy.static.akamaitechnologies.com | - | High
13 | [23.63.245.50](https://vuldb.com/?ip.23.63.245.50) | a23-63-245-50.deploy.static.akamaitechnologies.com | - | High
14 | [23.196.73.160](https://vuldb.com/?ip.23.196.73.160) | a23-196-73-160.deploy.static.akamaitechnologies.com | - | High
15 | [23.199.63.11](https://vuldb.com/?ip.23.199.63.11) | a23-199-63-11.deploy.static.akamaitechnologies.com | - | High
16 | [23.199.63.83](https://vuldb.com/?ip.23.199.63.83) | a23-199-63-83.deploy.static.akamaitechnologies.com | - | High
17 | [23.218.119.73](https://vuldb.com/?ip.23.218.119.73) | a23-218-119-73.deploy.static.akamaitechnologies.com | - | High
18 | [23.236.62.147](https://vuldb.com/?ip.23.236.62.147) | 147.62.236.23.bc.googleusercontent.com | - | Medium
19 | [27.254.87.155](https://vuldb.com/?ip.27.254.87.155) | cs56.hostneverdie.com | - | High
20 | [34.117.59.81](https://vuldb.com/?ip.34.117.59.81) | 81.59.117.34.bc.googleusercontent.com | - | Medium
21 | [34.195.145.145](https://vuldb.com/?ip.34.195.145.145) | ec2-34-195-145-145.compute-1.amazonaws.com | - | Medium
22 | [35.195.98.220](https://vuldb.com/?ip.35.195.98.220) | 220.98.195.35.bc.googleusercontent.com | - | Medium
23 | [35.205.61.67](https://vuldb.com/?ip.35.205.61.67) | 67.61.205.35.bc.googleusercontent.com | - | Medium
24 | ... | ... | ... | ...

There are 92 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _TeslaCrypt_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
2 | T1068 | CWE-264, CWE-284 | Execution with Unnecessary Privileges | High
3 | T1110.001 | CWE-798 | Improper Restriction of Excessive Authentication Attempts | High
4 | ... | ... | ... | ...

There are 4 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by TeslaCrypt. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.procmailrc` | Medium
2 | File | `/admin-ajax.php?action=eps_redirect_save` | High
3 | File | `/admin.php` | Medium
4 | File | `/auth` | Low
5 | File | `/dashboard/view-chair-list.php` | High
6 | File | `/etc/hosts` | Medium
7 | File | `/GponForm/device_Form?script/` | High
8 | File | `/GponForm/fsetup_Form` | High
9 | File | `/GponForm/usb_restore_Form?script/` | High
10 | File | `/includes/decorators/global-translations.jsp` | High
11 | File | `/index.php` | Medium
12 | File | `/product_list.php` | High
13 | File | `/secure/QueryComponent!Default.jspa` | High
14 | File | `/see_more_details.php` | High
15 | File | `/server-status` | High
16 | File | `/setSystemAdmin` | High
17 | File | `/uncpath/` | Medium
18 | File | `/usr/local/WowzaStreamingEngine/bin/` | High
19 | File | `/WEB-INF/web.xml` | High
20 | File | `addentry.php` | Medium
21 | File | `admin.php` | Medium
22 | File | `admin/executar_login.php` | High
23 | File | `admin/mcart_xls_import.php` | High
24 | File | `admin/setting.php` | High
25 | File | `admin_ranks.php` | High
26 | File | `ajax-actions.php` | High
27 | File | `alipay/alipayapi.php` | High
28 | File | `apcupsd.exe` | Medium
29 | File | `auth.inc.php` | Medium
30 | ... | ... | ...

There are 258 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2019/08/threat-roundup-0726-0802.html
* https://blog.talosintelligence.com/2019/08/threat-roundup-0823-0830.html
* https://blog.talosintelligence.com/2020/01/threat-roundup-0103-0110.html
* https://blog.talosintelligence.com/2020/01/threat-roundup-0124-0131.html
* https://blog.talosintelligence.com/2020/06/threat-roundup-0619-0626.html
* https://blog.talosintelligence.com/2020/07/threat-roundup-0724-0731.html
* https://blog.talosintelligence.com/2021/03/threat-roundup-0226-0305.html
* https://blog.talosintelligence.com/2021/10/threat-roundup-1001-1008.html
* https://blog.talosintelligence.com/2021/10/threat-roundup-1008-1015.html
* https://blog.talosintelligence.com/2022/01/threat-roundup-0114-0121.html
* https://blog.talosintelligence.com/2022/01/threat-roundup-0121-0128.html
* https://blog.talosintelligence.com/2022/02/threat-roundup-0128-0204.html
* https://blog.talosintelligence.com/2022/02/threat-roundup-0218-0225.html
* https://blog.talosintelligence.com/2022/05/threat-roundup-0513-0520.html

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
