# 0ktapus - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [0ktapus](https://vuldb.com/?actor.0ktapus). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.0ktapus](https://vuldb.com/?actor.0ktapus)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with 0ktapus:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [TK](https://vuldb.com/?country.tk)
* ...

There are 11 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of 0ktapus.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [45.32.66.165](https://vuldb.com/?ip.45.32.66.165) | 45.32.66.165.vultrusercontent.com | - | High
2 | [45.63.39.116](https://vuldb.com/?ip.45.63.39.116) | 45.63.39.116.vultrusercontent.com | - | High
3 | [45.63.39.151](https://vuldb.com/?ip.45.63.39.151) | 45.63.39.151.vultrusercontent.com | - | High
4 | [45.63.79.150](https://vuldb.com/?ip.45.63.79.150) | 45.63.79.150.vultrusercontent.com | - | High
5 | [45.76.80.199](https://vuldb.com/?ip.45.76.80.199) | 45.76.80.199.vultrusercontent.com | - | High
6 | [45.76.171.233](https://vuldb.com/?ip.45.76.171.233) | 45.76.171.233.vultrusercontent.com | - | High
7 | [45.76.238.53](https://vuldb.com/?ip.45.76.238.53) | 45.76.238.53.vultrusercontent.com | - | High
8 | [64.227.23.72](https://vuldb.com/?ip.64.227.23.72) | - | - | High
9 | [66.42.90.140](https://vuldb.com/?ip.66.42.90.140) | 66.42.90.140.vultrusercontent.com | - | High
10 | [66.42.91.138](https://vuldb.com/?ip.66.42.91.138) | 66.42.91.138.vultrusercontent.com | - | High
11 | [66.42.107.233](https://vuldb.com/?ip.66.42.107.233) | 66.42.107.233.vultrusercontent.com | - | High
12 | ... | ... | ... | ...

There are 45 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _0ktapus_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | ... | ... | ... | ...

There are 13 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by 0ktapus. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.htaccess` | Medium
2 | File | `/.env` | Low
3 | File | `/api/upload` | Medium
4 | File | `/domain/add` | Medium
5 | File | `/donor-wall` | Medium
6 | File | `/esbus/servlet/GetSQLData` | High
7 | File | `/film-rating.php` | High
8 | File | `/goform/formLogin` | High
9 | File | `/HNAP1` | Low
10 | File | `/horde/util/go.php` | High
11 | File | `/ishttpd/localweb/java/` | High
12 | File | `/KK_LS9ReportingPortal/GetData` | High
13 | File | `/mcategory.php` | High
14 | File | `/out.php` | Medium
15 | File | `/p` | Low
16 | File | `/uncpath/` | Medium
17 | File | `/usr/bin/uucp` | High
18 | File | `/usr/local/contego/scripts/mgrconfig.pl` | High
19 | File | `/web/google_analytics.php` | High
20 | File | `/webadmin.nsf/dlgFilesFolderNew` | High
21 | File | `/whbs/admin/?page=user` | High
22 | File | `/_readmail` | Medium
23 | File | `admin.php3` | Medium
24 | File | `admin/index.php?c=database` | High
25 | File | `admin/index.php?id=users/action=edit/user_id=1` | High
26 | File | `administrator/components/com_media/helpers/media.php` | High
27 | ... | ... | ...

There are 231 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.group-ib.com/0ktapus

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
