# B1txor20 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [B1txor20](https://vuldb.com/?actor.b1txor20). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.b1txor20](https://vuldb.com/?actor.b1txor20)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with B1txor20:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [SV](https://vuldb.com/?country.sv)
* ...

There are 8 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of B1txor20.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.2.69.50](https://vuldb.com/?ip.5.2.69.50) | - | - | High
2 | [23.129.64.216](https://vuldb.com/?ip.23.129.64.216) | - | - | High
3 | [23.154.177.4](https://vuldb.com/?ip.23.154.177.4) | - | - | High
4 | [45.13.104.179](https://vuldb.com/?ip.45.13.104.179) | nosoignons.cust.milkywan.net | - | High
5 | [45.61.185.90](https://vuldb.com/?ip.45.61.185.90) | MiamiTor4.us | - | High
6 | [45.154.255.147](https://vuldb.com/?ip.45.154.255.147) | cust-147.keff.org | - | High
7 | [46.166.139.111](https://vuldb.com/?ip.46.166.139.111) | - | - | High
8 | [51.15.43.205](https://vuldb.com/?ip.51.15.43.205) | 205-43-15-51.instances.scw.cloud | - | High
9 | [62.102.148.68](https://vuldb.com/?ip.62.102.148.68) | - | - | High
10 | [62.102.148.69](https://vuldb.com/?ip.62.102.148.69) | - | - | High
11 | [81.17.18.62](https://vuldb.com/?ip.81.17.18.62) | block1-che.interlayer.co.uk | - | High
12 | [104.244.73.126](https://vuldb.com/?ip.104.244.73.126) | lu1.exit.tor.alkyl.eu.org | - | High
13 | [109.201.133.100](https://vuldb.com/?ip.109.201.133.100) | . | - | High
14 | [162.247.74.27](https://vuldb.com/?ip.162.247.74.27) | turing.tor-exit.calyxinstitute.org | - | High
15 | ... | ... | ... | ...

There are 54 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _B1txor20_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-36 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94, CWE-1321 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | T1068 | CWE-264, CWE-269, CWE-273, CWE-284 | Execution with Unnecessary Privileges | High
7 | ... | ... | ... | ...

There are 22 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by B1txor20. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/?page=reports/stockin` | High
2 | File | `/admin/?page=reports/stockout` | High
3 | File | `/admin/?page=reports/waste` | High
4 | File | `/admin/?page=user/manage_user` | High
5 | File | `/admin/addemployee.php` | High
6 | File | `/admin/article/list` | High
7 | File | `/admin/article/list_approve` | High
8 | File | `/admin/contact/list` | High
9 | File | `/admin/del.php` | High
10 | File | `/admin/delete.php` | High
11 | File | `/admin/delstu.php` | High
12 | File | `/admin/foldernotice/list` | High
13 | File | `/admin/folderrollpicture/list` | High
14 | File | `/admin/image/list` | High
15 | File | `/admin/imagealbum/list` | High
16 | File | `/admin/login.php` | High
17 | File | `/admin/products/controller.php?action=add` | High
18 | File | `/admin/site/list` | High
19 | File | `/admin/videoalbum/list` | High
20 | File | `/advanced-tools/nova/bin/netwatch` | High
21 | File | `/api/upload-resource` | High
22 | File | `/appConfig/userDB.json` | High
23 | File | `/bd_genie_create_account.cgi` | High
24 | File | `/bin/boa` | Medium
25 | File | `/blog/edit` | Medium
26 | File | `/blogengine/api/posts` | High
27 | File | `/brand.php` | Medium
28 | File | `/carbon/ndatasource/validateconnection/ajaxprocessor.jsp` | High
29 | File | `/cgi-bin/DownloadFlash` | High
30 | File | `/cgi-bin/wlogin.cgi` | High
31 | File | `/classes/Master.php?f=delete_account` | High
32 | ... | ... | ...

There are 273 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.netlab.360.com/b1txor20-use-of-dns-tunneling_cn/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
