# Barys - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Barys](https://vuldb.com/?actor.barys). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.barys](https://vuldb.com/?actor.barys)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Barys:

* [US](https://vuldb.com/?country.us)
* [FR](https://vuldb.com/?country.fr)
* [JP](https://vuldb.com/?country.jp)
* ...

There are 2 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Barys.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [13.107.21.200](https://vuldb.com/?ip.13.107.21.200) | - | - | High
2 | [13.107.22.200](https://vuldb.com/?ip.13.107.22.200) | - | - | High
3 | [20.36.253.92](https://vuldb.com/?ip.20.36.253.92) | - | - | High
4 | [23.6.69.99](https://vuldb.com/?ip.23.6.69.99) | a23-6-69-99.deploy.static.akamaitechnologies.com | - | High
5 | [23.225.145.234](https://vuldb.com/?ip.23.225.145.234) | - | - | High
6 | [31.170.160.103](https://vuldb.com/?ip.31.170.160.103) | srv39.000webhost.com | - | High
7 | [34.232.187.93](https://vuldb.com/?ip.34.232.187.93) | ec2-34-232-187-93.compute-1.amazonaws.com | - | Medium
8 | [41.38.1.86](https://vuldb.com/?ip.41.38.1.86) | host-41.38.1.86.tedata.net | - | High
9 | [41.239.65.189](https://vuldb.com/?ip.41.239.65.189) | host-41.239.65.189.tedata.net | - | High
10 | [47.246.136.160](https://vuldb.com/?ip.47.246.136.160) | - | - | High
11 | [52.137.90.34](https://vuldb.com/?ip.52.137.90.34) | - | - | High
12 | [52.185.71.28](https://vuldb.com/?ip.52.185.71.28) | - | - | High
13 | ... | ... | ... | ...

There are 48 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Barys_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | ... | ... | ... | ...

There are 12 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Barys. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `$HOME/.cdrdao` | High
2 | File | `.FBCIndex` | Medium
3 | File | `/cgi-bin` | Medium
4 | File | `/cgi/cpaddons_feature.pl` | High
5 | File | `/dana/nc/ncrun.cgi` | High
6 | File | `/firewall/policy/` | High
7 | File | `/help/helpredir.aspx` | High
8 | File | `/irj/portal/` | Medium
9 | File | `/proc` | Low
10 | File | `/proc/net/ip6_flowlabel` | High
11 | File | `/search` | Low
12 | File | `/tmp/.pk11ipc1` | High
13 | File | `/tmp/adb.log` | Medium
14 | File | `/usr/bin/cu` | Medium
15 | File | `/var/crash/vmcore.log` | High
16 | File | `aclient.exe` | Medium
17 | File | `admin` | Low
18 | File | `admin.php` | Medium
19 | File | `admin.rssreader.php` | High
20 | File | `admin/batch_manager_unit.php` | High
21 | File | `admin/configuration/modifier.php` | High
22 | File | `admin/skins.php` | High
23 | File | `admin/system_manage/save.html` | High
24 | File | `admin/system_manage/user_config_add.html` | High
25 | File | `adminconsole` | Medium
26 | File | `administrator/mail/download.cfm` | High
27 | File | `admin_board.php` | High
28 | File | `af_netlink.c` | Medium
29 | File | `ajax.php` | Medium
30 | File | `ajaxRequest/methodCall.do` | High
31 | File | `announcements.php` | High
32 | File | `apache2/modsecurity.c` | High
33 | File | `apply.cgi` | Medium
34 | File | `app_new.php` | Medium
35 | File | `aspx` | Low
36 | File | `AttachmentsList.aspx` | High
37 | File | `Atx45.ocx` | Medium
38 | File | `auction_details.php` | High
39 | File | `auth-gss2.c` | Medium
40 | File | `auth.php` | Medium
41 | File | `aut_verifica.inc.php` | High
42 | File | `awsguest.php` | Medium
43 | File | `b2edit.showposts.php` | High
44 | File | `backend.php/screen.php/comment.php` | High
45 | File | `basicfunctions.php` | High
46 | File | `board.cgi` | Medium
47 | File | `bug_actiongroup_ext_page.php` | High
48 | File | `canned_opr.php` | High
49 | File | `cart.cgi` | Medium
50 | File | `cat.asp` | Low
51 | File | `cddbcontrolaol.cddbaolcontrol` | High
52 | ... | ... | ...

There are 456 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2019/04/threat-roundup-0329-0405.html
* https://blog.talosintelligence.com/2020/01/threat-roundup-0110-0117.html
* https://blog.talosintelligence.com/2020/06/threat-roundup-0529-0605.html
* https://blog.talosintelligence.com/2020/10/threat-roundup-0925-1002.html
* https://blog.talosintelligence.com/2020/12/threat-roundup-1127-1204.html
* https://blog.talosintelligence.com/2021/06/threat-roundup-0604-0611.html
* https://blog.talosintelligence.com/2021/08/threat-roundup-0820-0827.html
* https://blog.talosintelligence.com/2021/09/threat-roundup-0827-0903.html
* https://blog.talosintelligence.com/2022/01/threat-roundup-0121-0128.html

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
