# Black KingDom - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Black KingDom](https://vuldb.com/?actor.black_kingdom). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.black_kingdom](https://vuldb.com/?actor.black_kingdom)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Black KingDom:

* [US](https://vuldb.com/?country.us)
* [IT](https://vuldb.com/?country.it)
* [AR](https://vuldb.com/?country.ar)
* ...

There are 7 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Black KingDom.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [104.21.89.10](https://vuldb.com/?ip.104.21.89.10) | - | - | High
2 | [172.64.80.0](https://vuldb.com/?ip.172.64.80.0) | - | - | High
3 | [185.220.101.204](https://vuldb.com/?ip.185.220.101.204) | tor-exit-204.relayon.org | - | High
4 | ... | ... | ... | ...

There are 1 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Black KingDom_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-36 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 20 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Black KingDom. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/?page=reports/stockin` | High
2 | File | `/admin/?page=reports/waste` | High
3 | File | `/admin/?page=user/manage_user` | High
4 | File | `/admin/addemployee.php` | High
5 | File | `/admin/del.php` | High
6 | File | `/admin/delete.php` | High
7 | File | `/admin/delstu.php` | High
8 | File | `/admin/history.php` | High
9 | File | `/admin/login.php` | High
10 | File | `/admin/modify.php` | High
11 | File | `/admin/modify1.php` | High
12 | File | `/admin/products/controller.php?action=add` | High
13 | File | `/advanced-tools/nova/bin/netwatch` | High
14 | File | `/api/v1/user` | Medium
15 | File | `/appConfig/userDB.json` | High
16 | File | `/assets` | Low
17 | File | `/bin/boa` | Medium
18 | File | `/blog/edit` | Medium
19 | File | `/blogengine/api/posts` | High
20 | File | `/blotter/blotter.php` | High
21 | File | `/brand.php` | Medium
22 | File | `/cgi-bin/DownloadFlash` | High
23 | File | `/cgi-bin/wlogin.cgi` | High
24 | File | `/classes/Master.php?f=delete_account` | High
25 | File | `/classes/Master.php?f=delete_category` | High
26 | File | `/classes/Master.php?f=delete_img` | High
27 | File | `/classes/Master.php?f=delete_payment` | High
28 | ... | ... | ...

There are 232 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/sophoslabs/IoCs/blob/master/Ransomware_BlackKingDom.csv

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
