# DanaBot - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [DanaBot](https://vuldb.com/?actor.danabot). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.danabot](https://vuldb.com/?actor.danabot)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with DanaBot:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [AT](https://vuldb.com/?country.at)
* ...

There are 7 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of DanaBot.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.8.55.205](https://vuldb.com/?ip.5.8.55.205) | carpbaboon.com | - | High
2 | [5.9.224.217](https://vuldb.com/?ip.5.9.224.217) | static.217.224.9.5.clients.your-server.de | - | High
3 | [23.106.122.14](https://vuldb.com/?ip.23.106.122.14) | - | - | High
4 | [23.106.123.224](https://vuldb.com/?ip.23.106.123.224) | - | - | High
5 | [23.254.226.52](https://vuldb.com/?ip.23.254.226.52) | client-23-254-226-52.hostwindsdns.com | - | High
6 | [31.214.157.12](https://vuldb.com/?ip.31.214.157.12) | mail.private-mail.nl | - | High
7 | [45.147.231.79](https://vuldb.com/?ip.45.147.231.79) | - | - | High
8 | [46.173.218.13](https://vuldb.com/?ip.46.173.218.13) | - | - | High
9 | ... | ... | ... | ...

There are 32 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _DanaBot_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 16 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by DanaBot. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.htaccess` | Medium
2 | File | `/account/ResetPassword` | High
3 | File | `/addnews.html` | High
4 | File | `/cm/delete` | Medium
5 | File | `/download` | Medium
6 | File | `/forum/away.php` | High
7 | File | `/GetSimpleCMS-3.3.15/admin/log.php` | High
8 | File | `/lms/admin.php` | High
9 | File | `/my_photo_gallery/image.php` | High
10 | File | `/redpass.cgi` | Medium
11 | File | `/reps/classes/Users.php?f=delete_agent` | High
12 | File | `/rom-0` | Low
13 | File | `/secure/admin/ImporterFinishedPage.jspa` | High
14 | File | `/uncpath/` | Medium
15 | File | `/usr/ucb/mail` | High
16 | File | `adclick.php` | Medium
17 | File | `add-category.php` | High
18 | File | `add_comment.php` | High
19 | File | `admin.php` | Medium
20 | File | `admin/admin.shtml` | High
21 | ... | ... | ...

There are 171 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blogs.blackberry.com/en/2021/11/threat-thursday-danabot-malware-as-a-service
* https://community.blueliv.com/#!/s/6220736782df413eb5358bf6
* https://github.com/eset/malware-ioc/tree/master/danabot
* https://isc.sans.edu/forums/diary/Example+of+Danabot+distributed+through+malspam/27744/
* https://research.checkpoint.com/2019/danabot-demands-a-ransom-payment/
* https://twitter.com/CERT_OPL/status/1138810411149643777

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
