# Donot - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Donot](https://vuldb.com/?actor.donot). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.donot](https://vuldb.com/?actor.donot)

## Campaigns

The following _campaigns_ are known and can be associated with Donot:

* DarkMusical
* Gedit

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Donot:

* [US](https://vuldb.com/?country.us)
* [GB](https://vuldb.com/?country.gb)
* [TR](https://vuldb.com/?country.tr)
* ...

There are 24 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Donot.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.135.19.26](https://vuldb.com/?ip.5.135.19.26) | - | - | High
2 | [5.135.199.0](https://vuldb.com/?ip.5.135.199.0) | - | - | High
3 | [37.48.122.145](https://vuldb.com/?ip.37.48.122.145) | - | Gedit | High
4 | [37.120.140.211](https://vuldb.com/?ip.37.120.140.211) | - | - | High
5 | [37.120.198.208](https://vuldb.com/?ip.37.120.198.208) | - | DarkMusical | High
6 | [37.139.3.130](https://vuldb.com/?ip.37.139.3.130) | - | - | High
7 | [37.139.28.208](https://vuldb.com/?ip.37.139.28.208) | - | - | High
8 | [45.33.29.133](https://vuldb.com/?ip.45.33.29.133) | li1046-133.members.linode.com | - | High
9 | [45.61.137.7](https://vuldb.com/?ip.45.61.137.7) | - | - | High
10 | [46.101.204.168](https://vuldb.com/?ip.46.101.204.168) | - | - | High
11 | ... | ... | ... | ...

There are 39 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Donot_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 18 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Donot. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.htaccess` | Medium
2 | File | `/+CSCOE+/logon.html` | High
3 | File | `/.htpasswd` | Medium
4 | File | `/admin/index.php` | High
5 | File | `/bin/login.php` | High
6 | File | `/Category` | Medium
7 | File | `/de/cgi/dfs_guest/` | High
8 | File | `/event/runquery.do` | High
9 | File | `/filemanager/ajax_calls.php` | High
10 | File | `/htmlcode/html/indexdefault.asp` | High
11 | File | `/out.php` | Medium
12 | File | `/products/details.asp` | High
13 | File | `/share/error?message` | High
14 | File | `/system/ws/v11/ss/email` | High
15 | File | `/uncpath/` | Medium
16 | File | `/var/www/xms/application/config/config.php` | High
17 | File | `/var/www/xms/application/controllers/gatherLogs.php` | High
18 | File | `/var/www/xms/application/controllers/verifyLogin.php` | High
19 | File | `/var/www/xms/cleanzip.sh` | High
20 | File | `/web/jquery/uploader/multi_uploadify.php` | High
21 | File | `/wp-admin/admin-ajax.php` | High
22 | File | `/wp-content/plugins/woocommerce/templates/emails/plain/` | High
23 | File | `14all.cgi/14all-1.1.cgi/traffic.cgi/mrtg.cgi` | High
24 | File | `about.php` | Medium
25 | File | `adclick.php` | Medium
26 | File | `addentry.php` | Medium
27 | File | `add_vhost.php` | High
28 | File | `admin.php` | Medium
29 | File | `admin/conf_users_edit.php` | High
30 | File | `admin/default.asp` | High
31 | File | `admin/media/rename.php` | High
32 | File | `admin/user.php` | High
33 | File | `advanced_component_system/index.php` | High
34 | File | `agent.cfg` | Medium
35 | File | `ajax/render/widget_php` | High
36 | ... | ... | ...

There are 306 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.cyble.com/2021/07/22/donot-apt-group-delivers-a-spyware-variant-of-chat-app/
* https://github.com/faisalusuf/ThreatIntelligence/blob/main/APT%20DONOT%20TEAM/Tracking-DONOT-IOCs.csv
* https://twitter.com/ShadowChasing1/status/1497125743125413892
* https://www.welivesecurity.com/2022/01/18/donot-go-do-not-respawn/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
