# Fanel - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Fanel](https://vuldb.com/?actor.fanel). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.fanel](https://vuldb.com/?actor.fanel)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Fanel:

* [RO](https://vuldb.com/?country.ro)
* [US](https://vuldb.com/?country.us)
* [ES](https://vuldb.com/?country.es)
* ...

There are 6 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Fanel.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [34.67.140.147](https://vuldb.com/?ip.34.67.140.147) | 147.140.67.34.bc.googleusercontent.com | - | Medium
2 | [34.87.185.57](https://vuldb.com/?ip.34.87.185.57) | 57.185.87.34.bc.googleusercontent.com | - | Medium
3 | [34.93.240.37](https://vuldb.com/?ip.34.93.240.37) | 37.240.93.34.bc.googleusercontent.com | - | Medium
4 | [41.234.66.22](https://vuldb.com/?ip.41.234.66.22) | host-41.234.66.22.tedata.net | - | High
5 | [51.89.99.60](https://vuldb.com/?ip.51.89.99.60) | ns31180559.ip-51-89-99.eu | - | High
6 | [51.91.140.218](https://vuldb.com/?ip.51.91.140.218) | - | - | High
7 | ... | ... | ... | ...

There are 24 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Fanel_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 17 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Fanel. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/editer.php` | High
2 | File | `/admin/index/index.html#listarticle` | High
3 | File | `/bin/goahead` | Medium
4 | File | `/cgi-bin/kerbynet` | High
5 | File | `/cgi-bin/supervisor/PwdGrp.cgi` | High
6 | File | `/data/vendor/tcl` | High
7 | File | `/etc/postfix/sender_login` | High
8 | File | `/framework/core/models/expRecord.php` | High
9 | File | `/HNAP1` | Low
10 | File | `/htdocs/webinc/js/bsc_sms_inbox.php` | High
11 | File | `/manager?action=getlogcat` | High
12 | File | `/medicines` | Medium
13 | File | `/plugins/servlet/branchreview` | High
14 | File | `/proc` | Low
15 | File | `/Pwrchute` | Medium
16 | File | `/tmp` | Low
17 | File | `/tmp/.deepin-clone.log` | High
18 | File | `/users/{id}` | Medium
19 | File | `/usr/bin/pkexec` | High
20 | File | `/var/www/xms/application/controllers/verifyLogin.php` | High
21 | File | `actions.cpp` | Medium
22 | File | `adm1n/admin_config.php` | High
23 | File | `admin-ajax.php` | High
24 | File | `admin.php` | Medium
25 | File | `admin/addpage.php` | High
26 | File | `admin/admin_process.php` | High
27 | File | `admin/editusertag.php` | High
28 | File | `admin/eventlist.php` | High
29 | File | `admin/reklam_detay.asp` | High
30 | File | `admin/settings.php` | High
31 | File | `admin/snacks_edit.php` | High
32 | File | `admin/userview.php` | High
33 | File | `all_calendars.asp` | High
34 | File | `anniv.php` | Medium
35 | File | `api.php` | Low
36 | File | `app/search/search.app.php` | High
37 | File | `appGet.cgi` | Medium
38 | File | `apply.cgi` | Medium
39 | File | `arch/arm/kernel/perf_event.c` | High
40 | File | `ArticleType.php` | High
41 | File | `attachment.php` | High
42 | ... | ... | ...

There are 360 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/guardicore/labs_campaigns/tree/master/Fanel

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
