# ModPipe - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [ModPipe](https://vuldb.com/?actor.modpipe). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.modpipe](https://vuldb.com/?actor.modpipe)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with ModPipe:

* [US](https://vuldb.com/?country.us)
* [FR](https://vuldb.com/?country.fr)
* [ES](https://vuldb.com/?country.es)
* ...

There are 11 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of ModPipe.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.135.230.136](https://vuldb.com/?ip.5.135.230.136) | - | - | High
2 | [23.19.58.114](https://vuldb.com/?ip.23.19.58.114) | - | - | High
3 | [88.99.177.103](https://vuldb.com/?ip.88.99.177.103) | static.103.177.99.88.clients.your-server.de | - | High
4 | ... | ... | ... | ...

There are 3 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _ModPipe_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 15 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by ModPipe. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/access` | High
2 | File | `/admin/index.html` | High
3 | File | `/admin/index.php?id=themes&action=edit_template&filename=blog` | High
4 | File | `/admin/posts.php` | High
5 | File | `/ci_ssms/index.php/orders/create` | High
6 | File | `/fw.login.php` | High
7 | File | `/index.php` | Medium
8 | File | `/membres/modif_profil.php` | High
9 | File | `/ordering/admin/category/index.php?view=edit` | High
10 | File | `/pms/index.php` | High
11 | File | `/pms/update_user.php?user_id=1` | High
12 | File | `/SimpleBusTicket/index.php` | High
13 | File | `/tmp` | Low
14 | File | `/uncpath/` | Medium
15 | File | `/updown/upload.cgi` | High
16 | File | `/usr/bin/pkexec` | High
17 | File | `/wp-admin/admin-ajax.php` | High
18 | File | `14all.cgi/14all-1.1.cgi/traffic.cgi/mrtg.cgi` | High
19 | File | `addpost_newpoll.php` | High
20 | File | `adm-index.php` | High
21 | File | `Admin.PHP` | Medium
22 | File | `admin.php` | Medium
23 | File | `admin/index.php` | High
24 | File | `admin/ops/reports/ops/forum.php` | High
25 | File | `admincp/attachment.php` | High
26 | File | `adminedit.pl` | Medium
27 | File | `ajax/api/hook/getHookList` | High
28 | File | `archive/index.php` | High
29 | File | `backend/groups/index.php` | High
30 | File | `bbs/member_confirm.php` | High
31 | File | `bottom.php` | Medium
32 | File | `breadcrumbs_create.php` | High
33 | File | `C:\Program Files\FileZilla FTP Client\uninstall.exe` | High
34 | File | `cds-fpdf.php` | Medium
35 | File | `connector.php` | High
36 | File | `controllers/member/Api.php` | High
37 | File | `cp.php` | Low
38 | File | `dashboard_teacher.php` | High
39 | File | `data/gbconfiguration.dat` | High
40 | File | `demo.php` | Medium
41 | File | `dev.c` | Low
42 | ... | ... | ...

There are 359 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://community.blueliv.com/#!/s/5fad26c782df413eb535189f

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
