# PureCrypter - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [PureCrypter](https://vuldb.com/?actor.purecrypter). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.purecrypter](https://vuldb.com/?actor.purecrypter)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with PureCrypter:

* [US](https://vuldb.com/?country.us)
* [FR](https://vuldb.com/?country.fr)

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of PureCrypter.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [37.0.11.164](https://vuldb.com/?ip.37.0.11.164) | - | - | High
2 | [45.143.201.4](https://vuldb.com/?ip.45.143.201.4) | - | - | High
3 | [62.204.41.69](https://vuldb.com/?ip.62.204.41.69) | - | - | High
4 | ... | ... | ... | ...

There are 5 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _PureCrypter_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23 | Pathname Traversal | High
2 | T1059 | CWE-94 | Cross Site Scripting | High
3 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
4 | ... | ... | ... | ...

There are 11 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by PureCrypter. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/about.php` | Medium
2 | File | `/admin.php` | Medium
3 | File | `/admin/doctors/view_doctor.php` | High
4 | File | `/admin/modules/bibliography/index.php` | High
5 | File | `/adminlogin.asp` | High
6 | File | `/app/controller/Books.php` | High
7 | File | `/aqpg/users/login.php` | High
8 | File | `/controller/Index.php` | High
9 | File | `/coreframe/app/content/admin/content.php` | High
10 | File | `/dl/dl_print.php` | High
11 | File | `/etc/master.passwd` | High
12 | File | `/etc/passwd` | Medium
13 | File | `/Hospital-Management-System-master/contact.php` | High
14 | File | `/include/friends.inc.php` | High
15 | File | `/members/view_member.php` | High
16 | File | `/servlet/webacc` | High
17 | File | `/sitemagic/upgrade.php` | High
18 | File | `/userui/ticket_list.php` | High
19 | File | `/wp-admin/options-general.php` | High
20 | File | `/zm/index.php` | High
21 | File | `abook_database.php` | High
22 | File | `accounts/inc/include.php` | High
23 | File | `adaptive-images-script.php` | High
24 | File | `additem.asp` | Medium
25 | File | `addtocart.asp` | High
26 | File | `adherents/subscription/info.php` | High
27 | File | `admin.asp` | Medium
28 | File | `admin.php` | Medium
29 | File | `admin/admin.php` | High
30 | File | `admin/admin_users.php` | High
31 | File | `admin/general.php` | High
32 | File | `admin/header.php` | High
33 | File | `admin/inc/change_action.php` | High
34 | File | `admin/index.php` | High
35 | File | `admin/info.php` | High
36 | File | `admin/login.asp` | High
37 | File | `admin/manage-comments.php` | High
38 | File | `admin/manage-news.php` | High
39 | File | `admin/plugin-settings.php` | High
40 | File | `admin/specials.php` | High
41 | File | `admin:de` | Medium
42 | File | `admincp/auth/checklogin.php` | High
43 | File | `admincp/auth/secure.php` | High
44 | File | `administrator/components/com_media/helpers/media.php` | High
45 | File | `administrator/index.php` | High
46 | File | `admin_login.asp` | High
47 | File | `adv_search.asp` | High
48 | File | `ajax/aj_*.php` | High
49 | File | `ajax_url.php` | Medium
50 | File | `album_portal.php` | High
51 | File | `al_initialize.php` | High
52 | File | `anjel.index.php` | High
53 | File | `annonces-p-f.php` | High
54 | File | `announce.php` | Medium
55 | File | `announcement.php` | High
56 | File | `announcements.php` | High
57 | File | `app/admin/routing/edit-bgp-mapping-search.php` | High
58 | File | `application/config/config.php` | High
59 | File | `apply.cgi` | Medium
60 | File | `apps/app_article/controller/rating.php` | High
61 | File | `article.php` | Medium
62 | File | `articles.php` | Medium
63 | File | `artikel_anzeige.php` | High
64 | File | `auktion.cgi` | Medium
65 | File | `auth.php` | Medium
66 | File | `authfiles/login.asp` | High
67 | File | `basket.php` | Medium
68 | File | `boardData103.php/boardDataJP.php/boardDataNA.php/boardDataWW.php` | High
69 | File | `books.php` | Medium
70 | File | `browse-category.php` | High
71 | File | `browse.php` | Medium
72 | File | `browse_videos.php` | High
73 | File | `BrudaNews/BrudaGB` | High
74 | File | `bwlist_inc.html` | High
75 | File | `calendar.php` | Medium
76 | File | `callme_page.php` | High
77 | File | `cart.php` | Medium
78 | File | `cart_add.php` | Medium
79 | File | `case.filemanager.php` | High
80 | File | `catalog.php` | Medium
81 | File | `catalogshop.php` | High
82 | File | `catalogue.asp` | High
83 | File | `category.cfm` | Medium
84 | File | `category.php` | Medium
85 | File | `category_list.php` | High
86 | File | `cgi-bin/awstats.pl` | High
87 | File | `channel.asp` | Medium
88 | File | `ChooseCpSearch.php` | High
89 | File | `comentarii.php` | High
90 | File | `comments.php` | Medium
91 | File | `config.inc.php` | High
92 | ... | ... | ...

There are 816 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.netlab.360.com/purecrypter/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
