# Rocket Kitten - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Rocket Kitten](https://vuldb.com/?actor.rocket_kitten). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.rocket_kitten](https://vuldb.com/?actor.rocket_kitten)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Rocket Kitten:

* [US](https://vuldb.com/?country.us)
* [IR](https://vuldb.com/?country.ir)
* [ES](https://vuldb.com/?country.es)
* ...

There are 7 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Rocket Kitten.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [83.170.33.37](https://vuldb.com/?ip.83.170.33.37) | host-83-170-33-37.customer.teleport-iabg.de | - | High
2 | [83.170.33.60](https://vuldb.com/?ip.83.170.33.60) | host-83-170-33-60.customer.teleport-iabg.de | - | High
3 | [83.170.33.80](https://vuldb.com/?ip.83.170.33.80) | host-83-170-33-80.customer.teleport-iabg.de | - | High
4 | ... | ... | ... | ...

There are 2 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Rocket Kitten_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 18 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Rocket Kitten. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.htaccess` | Medium
2 | File | `/admin.php` | Medium
3 | File | `/admin/book/create/` | High
4 | File | `/admin/loginc.php` | High
5 | File | `/auditLogAction.do` | High
6 | File | `/cgi-bin/wapopen` | High
7 | File | `/devices/acurite.c` | High
8 | File | `/etc/ajenti/config.yml` | High
9 | File | `/etc/sudoers` | Medium
10 | File | `/example/editor` | High
11 | File | `/getcfg.php` | Medium
12 | File | `/GetCSSashx/?CP=%2fwebconfig` | High
13 | File | `/goform/login_process` | High
14 | File | `/goform/rlmswitchr_process` | High
15 | File | `/goforms/rlminfo` | High
16 | File | `/newsDia.php` | Medium
17 | File | `/plugin` | Low
18 | File | `/rating.php` | Medium
19 | File | `/scas/admin/` | Medium
20 | File | `/scas/classes/Users.php?f=save_user` | High
21 | File | `/services/prefs.php` | High
22 | File | `/src/njs_object.c` | High
23 | File | `/uncpath/` | Medium
24 | File | `/wordpress-gallery-transformation/gallery.php` | High
25 | File | `adclick.php` | Medium
26 | ... | ... | ...

There are 214 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://isc.sans.edu/forums/diary/Rocket+Kitten+Is+it+still+APT+if+you+can+buy+it+off+the+shelf/19123/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
