# Snatch - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Snatch](https://vuldb.com/?actor.snatch). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.snatch](https://vuldb.com/?actor.snatch)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Snatch:

* [US](https://vuldb.com/?country.us)
* [DE](https://vuldb.com/?country.de)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 16 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Snatch.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [37.59.146.180](https://vuldb.com/?ip.37.59.146.180) | ip180.ip-37-59-146.eu | - | High
2 | [45.147.228.91](https://vuldb.com/?ip.45.147.228.91) | - | - | High
3 | [67.211.209.151](https://vuldb.com/?ip.67.211.209.151) | vps2367725.trouble-free.net | - | High
4 | ... | ... | ... | ...

There are 8 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Snatch_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 17 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Snatch. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `%PROGRAMDATA%\WrData\PKG` | High
2 | File | `/.ssh/authorized_keys` | High
3 | File | `/assets/components/gallery/connector.php` | High
4 | File | `/College/admin/teacher.php` | High
5 | File | `/editbrand.php` | High
6 | File | `/etc/target` | Medium
7 | File | `/export` | Low
8 | File | `/getcfg.php` | Medium
9 | File | `/goform/WriteFacMac` | High
10 | File | `/index.php` | Medium
11 | File | `/lists/admin/user.php` | High
12 | File | `/movie.php` | Medium
13 | File | `/news-portal-script/information.php` | High
14 | File | `/tmp` | Low
15 | File | `/uncpath/` | Medium
16 | File | `/wp-content/plugins/updraftplus/admin.php` | High
17 | File | `/_vti_pvt/access.cnf` | High
18 | File | `admin.php3` | Medium
19 | File | `admin/mobile.php` | High
20 | File | `admin/themes` | Medium
21 | File | `administration/comments.php` | High
22 | File | `admin_hacks_list.php` | High
23 | ... | ... | ...

There are 194 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/sophoslabs/IoCs/blob/master/Ransomware-Snatch
* https://thedfirreport.com/2020/06/21/snatch-ransomware/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
