# VBShower - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [VBShower](https://vuldb.com/?actor.vbshower). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.vbshower](https://vuldb.com/?actor.vbshower)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with VBShower:

* [IT](https://vuldb.com/?country.it)
* [AR](https://vuldb.com/?country.ar)
* [ES](https://vuldb.com/?country.es)
* ...

There are 6 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of VBShower.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [144.217.174.57](https://vuldb.com/?ip.144.217.174.57) | ip57.ip-144-217-174.net | - | High
2 | [176.31.59.232](https://vuldb.com/?ip.176.31.59.232) | - | - | High

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _VBShower_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 17 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by VBShower. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/comment/list` | High
2 | File | `/admin/header.inc.php` | High
3 | File | `/admin/login.php` | High
4 | File | `/admin/plugins/NP_Referrer.php` | High
5 | File | `/admin/products/controller.php?action=add` | High
6 | File | `/admin/site/list` | High
7 | File | `/AJAX/ajaxget` | High
8 | File | `/ajax/clear_tools_log/` | High
9 | File | `/api/` | Low
10 | File | `/api/v2/labels/` | High
11 | File | `/bin/posix/src/ports/POSIX/OpENer` | High
12 | File | `/cgi-bin/ExportSettings.sh` | High
13 | File | `/claire_blake` | High
14 | File | `/classes/Master.php?f=delete_train` | High
15 | File | `/common/bbox.cpp` | High
16 | File | `/dotrace.asp` | Medium
17 | File | `/etc/fstab` | Medium
18 | File | `/etc/origin/master/master-config.yaml` | High
19 | File | `/etc/shadow.sample` | High
20 | File | `/footer.inc.php` | High
21 | File | `/gasmark/assets/myimages/oneWord.php` | High
22 | File | `/goform/formWifiBasicSet` | High
23 | File | `/goform/saveParentControlInfo` | High
24 | File | `/home/www/cgi-bin/login.cgi` | High
25 | File | `/htdocs/utils/Files.php` | High
26 | File | `/include/notify.inc.php` | High
27 | File | `/index.php?route=extension/module/so_filter_shop_by/filter_data` | High
28 | File | `/list` | Low
29 | File | `/master/index.php` | High
30 | File | `/mdiy/model/delete` | High
31 | File | `/modules/tasks/gantt.php` | High
32 | File | `/net/nfc/netlink.c` | High
33 | File | `/pages/permit/permit.php` | High
34 | File | `/patient/settings.php` | High
35 | File | `/pms/update_user.php?user_id=1` | High
36 | File | `/ptipupgrade.cgi` | High
37 | File | `/release-x64/otfccdump` | High
38 | File | `/staff/lab.php` | High
39 | File | `/student/dele.php` | High
40 | File | `/superguestconfig` | High
41 | File | `/tmp` | Low
42 | File | `/upload/admin.php?/deal/` | High
43 | File | `/usr/sbin/sendmail` | High
44 | File | `/var/log/qualys/qualys-cloud-agent-scan.log` | High
45 | File | `/var/run/watchman.pid` | High
46 | File | `/www/cgi-bin/popen.cgi` | High
47 | File | `/xpdf/AcroForm.cc` | High
48 | File | `/xpdf/Stream.cc` | High
49 | File | `action-visitor.php` | High
50 | File | `add.php` | Low
51 | File | `addlinksform.php` | High
52 | ... | ... | ...

There are 448 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://securelist.com/recent-cloud-atlas-activity/92016/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
