# Accellion FTA Webshell - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _Accellion FTA Webshell_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Accellion FTA Webshell:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 20 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with Accellion FTA Webshell or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Unknown](https://vuldb.com/?actor.unknown) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Accellion FTA Webshell.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [45.135.229.179](https://vuldb.com/?ip.45.135.229.179) | ipcore3.example.com | [Unknown](https://vuldb.com/?actor.unknown) | High
2 | [79.141.162.82](https://vuldb.com/?ip.79.141.162.82) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
3 | [92.38.135.29](https://vuldb.com/?ip.92.38.135.29) | camerotn1.com | [Unknown](https://vuldb.com/?actor.unknown) | High
4 | ... | ... | ... | ...

There are 6 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within Accellion FTA Webshell. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 17 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during Accellion FTA Webshell. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.FBCIndex` | Medium
2 | File | `.htaccess` | Medium
3 | File | `/+CSCOE+/logon.html` | High
4 | File | `/anony/mjpg.cgi` | High
5 | File | `/api/RecordingList/DownloadRecord?file=` | High
6 | File | `/authenticate.php` | High
7 | File | `/cache/backup/` | High
8 | File | `/cameras/XXXX/clips` | High
9 | File | `/category.php` | High
10 | File | `/cgi-bin` | Medium
11 | File | `/cgi-bin/wapopen` | High
12 | File | `/cwp_{SESSION_HASH}/admin/loader_ajax.php` | High
13 | File | `/data/vendor/tcl` | High
14 | File | `/debug/pprof` | Medium
15 | File | `/DLSnap` | Low
16 | File | `/exec/` | Low
17 | File | `/items/view_item.php` | High
18 | File | `/ldclient/ldprov.cgi` | High
19 | File | `/librarian/bookdetails.php` | High
20 | File | `/login` | Low
21 | File | `/mail/index.html` | High
22 | File | `/mgmt/tm/util/bash` | High
23 | File | `/plugin/extended-choice-parameter/js/` | High
24 | File | `/plugins/servlet/gadgets/makeRequest` | High
25 | File | `/PreviewHandler.ashx` | High
26 | File | `/products/details.asp` | High
27 | File | `/rest/api/2/user/picker` | High
28 | File | `/rest/api/latest/groupuserpicker` | High
29 | File | `/rom-0` | Low
30 | File | `/secure/QueryComponent!Default.jspa` | High
31 | File | `/services/details.asp` | High
32 | File | `/student/bookdetails.php` | High
33 | File | `/templates/header.inc.php` | High
34 | File | `/uncpath/` | Medium
35 | File | `/usr/bin/pkexec` | High
36 | File | `/usr/local/contego/scripts/mgrconfig.pl` | High
37 | File | `/var/log/nginx` | High
38 | ... | ... | ...

There are 331 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://us-cert.cisa.gov/ncas/analysis-reports/ar21-055a

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
