# CVE-2022-22954 and CVE-2022-22960 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _CVE-2022-22954 and CVE-2022-22960_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with CVE-2022-22954 and CVE-2022-22960:

* [DE](https://vuldb.com/?country.de)

## Actors

These _actors_ are associated with CVE-2022-22954 and CVE-2022-22960 or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Unknown](https://vuldb.com/?actor.unknown) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of CVE-2022-22954 and CVE-2022-22960.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [136.243.75.136](https://vuldb.com/?ip.136.243.75.136) | static.136.75.243.136.clients.your-server.de | [Unknown](https://vuldb.com/?actor.unknown) | High

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within CVE-2022-22954 and CVE-2022-22960. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1059 | CWE-94 | Cross Site Scripting | High
3 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
4 | T1068 | CWE-264, CWE-266, CWE-269, CWE-274, CWE-284 | Execution with Unnecessary Privileges | High
5 | ... | ... | ... | ...

There are 15 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during CVE-2022-22954 and CVE-2022-22960. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/alumni/admin/ajax.php?action=save_settings` | High
2 | File | `/bin/false` | Medium
3 | File | `/concat?/%2557EB-INF/web.xml` | High
4 | File | `/core/kernels/ctc_decoder_ops.cc` | High
5 | File | `/etc/` | Low
6 | File | `/etc/controller-agent/agent.conf` | High
7 | File | `/Filespec` | Medium
8 | File | `/firewall/schedule/recurrdlg` | High
9 | File | `/index.php/weblinks-categories` | High
10 | File | `/lib/` | Low
11 | File | `/proc/pid/status` | High
12 | File | `/run/spice-vdagentd/spice-vdagent-sock` | High
13 | File | `/tmp/.X11-unix/` | High
14 | File | `/users/{id}` | Medium
15 | File | `/var/run/jboss-eap/` | High
16 | File | `admin.php` | Medium
17 | File | `admin/define_language.php` | High
18 | File | `admin/index.php` | High
19 | File | `admin/index.php?module=rootpwd` | High
20 | File | `admin/info.php?shuyu` | High
21 | File | `admin/moduleinterface.php` | High
22 | File | `Administration/Controllers/ImportController.cs` | High
23 | File | `advancedsetup_websiteblocking.html` | High
24 | File | `ajax_admin_apis.php` | High
25 | ... | ... | ...

There are 206 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://www.cisa.gov/uscert/ncas/alerts/aa22-138b

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
