# Kazakhstan - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _Kazakhstan_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Kazakhstan:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [IT](https://vuldb.com/?country.it)
* ...

There are 6 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with Kazakhstan or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Unknown](https://vuldb.com/?actor.unknown) | High
2 | [Calypso](https://vuldb.com/?actor.calypso) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Kazakhstan.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [2.228.150.86](https://vuldb.com/?ip.2.228.150.86) | 2-228-150-86.ip192.fastwebnet.it | [Unknown](https://vuldb.com/?actor.unknown) | High
2 | [2.229.68.182](https://vuldb.com/?ip.2.229.68.182) | 2-229-68-182.ip195.fastwebnet.it | [Unknown](https://vuldb.com/?actor.unknown) | High
3 | [5.183.178.181](https://vuldb.com/?ip.5.183.178.181) | - | [Calypso](https://vuldb.com/?actor.calypso) | High
4 | [5.188.228.53](https://vuldb.com/?ip.5.188.228.53) | indppur1.example.com | [Calypso](https://vuldb.com/?actor.calypso) | High
5 | [45.32.184.101](https://vuldb.com/?ip.45.32.184.101) | 45.32.184.101.vultrusercontent.com | [Unknown](https://vuldb.com/?actor.unknown) | High
6 | [45.63.114.127](https://vuldb.com/?ip.45.63.114.127) | 45.63.114.127.vultrusercontent.com | [Unknown](https://vuldb.com/?actor.unknown) | High
7 | ... | ... | ... | ...

There are 25 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within Kazakhstan. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 17 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during Kazakhstan. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/template.php` | High
2 | File | `/admin/user/manage/add` | High
3 | File | `/export` | Low
4 | File | `/iisadmin` | Medium
5 | File | `/inc/parser/xhtml.php` | High
6 | File | `/includes/lib/detail.php` | High
7 | File | `/MIME/INBOX-MM-1/` | High
8 | File | `/ptms/classes/Users.php` | High
9 | File | `/public/plugins/` | High
10 | File | `/rest/api/1.0/render` | High
11 | File | `/scripts/iisadmin/bdir.htr` | High
12 | File | `/WEB-INF/web.xml` | High
13 | ... | ... | ...

There are 103 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://blog.google/threat-analysis-group/italian-spyware-vendor-targets-users-in-italy-and-kazakhstan/
* https://news.drweb.com/show/?i=14451
* https://st.drweb.co.jp/static/new-www/news/2020/july/Study_of_the_APT_attacks_on_state_institutions_in_Kazakhstan_and_Kyrgyzstan_en.pdf
* https://st.drweb.com/static/new-www/news/2022/march/telecom_research_en.pdf

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
