# M365 Phishing with MFA - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _M365 Phishing with MFA_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with M365 Phishing with MFA:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [GB](https://vuldb.com/?country.gb)
* ...

There are 19 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with M365 Phishing with MFA or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Unknown](https://vuldb.com/?actor.unknown) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of M365 Phishing with MFA.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [85.203.46.65](https://vuldb.com/?ip.85.203.46.65) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
2 | [85.203.46.213](https://vuldb.com/?ip.85.203.46.213) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
3 | [185.192.71.57](https://vuldb.com/?ip.185.192.71.57) | - | [Unknown](https://vuldb.com/?actor.unknown) | High

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within M365 Phishing with MFA. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 15 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during M365 Phishing with MFA. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/ClickAndBanexDemo/admin/admin.asp` | High
2 | File | `/configs/application.ini` | High
3 | File | `/HNAP1` | Low
4 | File | `/iissamples/sdk/asp/interaction/Form_JScript.asp` | High
5 | File | `/index.php` | Medium
6 | File | `/iwgallery/admin/pictures_edit.asp` | High
7 | File | `/mail/index.html` | High
8 | File | `/public/plugins/` | High
9 | File | `/replication` | Medium
10 | File | `/TeamMate/Upload/DomainObjectDocumentUpload.ashx` | High
11 | File | `/uncpath/` | Medium
12 | File | `/uploads/dede` | High
13 | File | `/WEB-INF/web.xml` | High
14 | File | `AccessPoint.aspx` | High
15 | File | `activateuser.aspx` | High
16 | File | `AdHocQuery_Processor.aspx` | High
17 | File | `admin.asp` | Medium
18 | File | `admin/admin.asp` | High
19 | File | `admin/images.aspx` | High
20 | File | `admin/index.php` | High
21 | File | `admin/login.asp` | High
22 | File | `advsearch.asp` | High
23 | File | `AEAgent.cpp` | Medium
24 | File | `ajax.php` | Medium
25 | File | `ajax_calls.php` | High
26 | File | `ajax_cmd.php` | Medium
27 | File | `appfeed.c` | Medium
28 | File | `ara.asp` | Low
29 | File | `aspx` | Low
30 | File | `auction_details.php` | High
31 | File | `auth.inc.php` | Medium
32 | ... | ... | ...

There are 275 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://github.com/hvs-consulting/ioc_signatures/blob/main/M365_MFA_Phishing/HvS_M365_MFA_Phishing_2022-01_IOCs.csv

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
