# MagicRAT - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _MagicRAT_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with MagicRAT:

* [US](https://vuldb.com/?country.us)
* [PL](https://vuldb.com/?country.pl)
* [FR](https://vuldb.com/?country.fr)
* ...

There are 3 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with MagicRAT or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Lazarus](https://vuldb.com/?actor.lazarus) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of MagicRAT.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [52.202.193.124](https://vuldb.com/?ip.52.202.193.124) | ec2-52-202-193-124.compute-1.amazonaws.com | [Lazarus](https://vuldb.com/?actor.lazarus) | Medium
2 | [64.188.27.73](https://vuldb.com/?ip.64.188.27.73) | 64.188.27.73.static.quadranet.com | [Lazarus](https://vuldb.com/?actor.lazarus) | High
3 | [66.154.102.91](https://vuldb.com/?ip.66.154.102.91) | 66.154.102.91.static.quadranet.com | [Lazarus](https://vuldb.com/?actor.lazarus) | High
4 | ... | ... | ... | ...

There are 2 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within MagicRAT. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-88, CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 16 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during MagicRAT. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.htaccess` | Medium
2 | File | `/admin/loginc.php` | High
3 | File | `/admin/students/view_student.php` | High
4 | File | `/Applications/Calculator.app/Contents/MacOS/Calculator` | High
5 | File | `/cgi-bin/` | Medium
6 | File | `/cgi-bin/luci` | High
7 | File | `/common/info.cgi` | High
8 | File | `/config.cgi?webmin` | High
9 | File | `/data/inc/images.php` | High
10 | File | `/dev/block/mmcblk0rpmb` | High
11 | File | `/edit` | Low
12 | File | `/etc/passwd` | Medium
13 | File | `/etc/stunnel.key` | High
14 | File | `/etc/sysconfig/btrfsmaintenance` | High
15 | File | `/framework/modules/notfound/controllers/notfoundController.php` | High
16 | File | `/gadgets/definitions/uptime.CapacityWhatIfGadget/getmetrics.php` | High
17 | File | `/job-details` | Medium
18 | File | `/mib.db` | Low
19 | File | `/page/add` | Medium
20 | File | `/squashfs-root/www/HNAP1/control/SetWizardConfig.php` | High
21 | File | `/system-info/health` | High
22 | File | `/tmp/s48lose.tmp` | High
23 | File | `/tmp/xbindkeysrc-tmp` | High
24 | File | `/uncpath/` | Medium
25 | File | `/usr/local` | Medium
26 | File | `/var/log/nginx` | High
27 | File | `/var/run/jboss-eap/` | High
28 | File | `admin-ajax.php` | High
29 | File | `admin.jcomments.php` | High
30 | File | `admin.php` | Medium
31 | File | `admin/?n=language&c=language_general&a=doSearchParameter` | High
32 | File | `admin/?n=user&c=admin_user&a=doGetUserInfo` | High
33 | File | `admin/admin_log/index.html?user_id` | High
34 | File | `admin/admin_menu.php` | High
35 | File | `admin/config.php` | High
36 | ... | ... | ...

There are 308 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://blog.talosintelligence.com/2022/09/lazarus-magicrat.html

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2022](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
